package persistence.category;

import category.Category;
import category.CategoryId;
import category.CategoryName;
import persistence.csv.CSVSerializable;

public class CategoryEntity implements CSVSerializable {

	private final String name;
	private final int id;

	public CategoryEntity(String name, int id) {
		this.name = name;
		this.id = id;
	}

	public CategoryEntity(String[] fields) {
		this(fields[0], Integer.parseInt(fields[1]));
	}

	public CategoryEntity(Category category) {
		this(category.getName().toString(), category.getId().id());
	}

	public Category toCategory() {
		return new Category(new CategoryName(name), new CategoryId(id));
	}

	@Override
	public String[] getHeaders() {
		return new String[]{"name", "id"};
	}

	@Override
	public String toCSVString() {
		return name + CSVSerializable.seperator + Integer.toString(id);
	}
}
